@@ -34,6 +34,23 @@ def typecode(typename):
 
 # ------------------ Find object definitions -----------------
 
+def strip_comments(buf):
+    parts = []
+    lastpos = 0
+    while 1:
+        pos = string.find(buf, '/*', lastpos)
+        if pos >= 0:
+            parts.append(buf[lastpos:pos])
+            pos = string.find(buf, '*/', pos)
+            if pos >= 0:
+                lastpos = pos + 2
+            else:
+                break
+        else:
+            parts.append(buf[lastpos:])
+            break
+    return string.join(parts, '')
+
 obj_name_pat = "[A-Z][a-z]*[A-Z][A-Za-z0-9]*"
 
 split_prefix_pat = re.compile('([A-Z][a-z]*)([A-Za-z0-9]+)')
@@ -44,8 +61,7 @@ def find_obj_defs(buf, objdefs=[]):
     """
 
     # filter out comments from buffer.
-    pat = re.compile(r"""/[*](.|\n)*?[*]/""", re.MULTILINE)
-    buf=pat.sub('',buf)
+    buf = strip_comments(buf)
 
     maybeobjdefs = []  # contains all possible objects from file
 
@@ -147,8 +163,7 @@ def write_obj_defs(objdefs, output):
 def find_enum_defs(buf, enums=[]):
     # strip comments
     # bulk comments
-    pat = re.compile(r"""/[*](.|\n)*?[*]/""", re.MULTILINE)
-    buf=pat.sub('',buf)
+    buf = strip_comments(buf)
 
     buf = re.sub('\n', ' ', buf)
     
@@ -212,8 +227,6 @@ def write_enum_defs(enums, output=None):
 
 # ------------------ Find function definitions -----------------
 
-#comment_pat = re.compile(r"""(/[*](.|\n)*?[*]/)|(^;.*$)""", re.MULTILINE)
-
 def clean_func(buf):
     """
     Ideally would make buf have a single prototype on each line.
@@ -221,7 +234,10 @@ def clean_func(buf):
     where a regex can figure prototypes out.
     """
     # bulk comments
-    pat = re.compile(r"""/[*](.|\n)*?[*]/""", re.MULTILINE)
+    buf = strip_comments(buf)
+
+    # compact continued lines
+    pat = re.compile(r"""\\\n""", re.MULTILINE) 
     buf=pat.sub('',buf)
 
     # Preprocess directives
@@ -239,6 +255,7 @@ def clean_func(buf):
     #clean up line ends
     pat = re.compile(r""";\s*""", re.MULTILINE) 
     buf=pat.sub('\n',buf)
+    buf = buf.lstrip()
 
     #associate *, &, and [] with type instead of variable
     #pat=re.compile(r'\s+([*|&]+)\s*(\w+)')
@@ -284,6 +301,8 @@ def define_func(buf,fp):
         write_func(fp, func, ret, args)
 
 get_type_pat = re.compile(r'(const-)?([A-Za-z0-9]+)\*?\s+')
+pointer_pat = re.compile('.*\*$')
+func_new_pat = re.compile('(\w+)_new$')
 
 def write_func(fp, name, ret, args):
     if len(args) >= 1:
@@ -322,10 +341,19 @@ def write_func(fp, name, ret, args):
                 fp.write(')\n\n')
                 return
     # it is either a constructor or normal function
-    # FIXME: put in constructor check
     fp.write('(define-function ' + name + '\n')
-    # do in-module thingee
     fp.write('  (c-name "' + name + '")\n')
+
+    # Hmmm... Let's asume that a constructor function name
+    # ends with '_new' and it returns a pointer.
+    m = func_new_pat.match(name)
+    if pointer_pat.match(ret) and m:
+        cname = ''
+	for s in m.group(1).split ('_'):
+	    cname += s.title()
+	if cname != '':
+	    fp.write('  (is-constructor-of "' + cname + '")\n')
+
     if ret != 'void':
         fp.write('  (return-type "' + ret + '")\n')
     else:
