@@ -1,4 +1,24 @@
-/* -*- Mode: C; c-basic-offset: 4 -*- */
+/* -*- Mode: C; c-basic-offset: 4 -*-
+ * pygtk- Python bindings for the GTK toolkit.
+ * Copyright (C) 1998-2003  James Henstridge
+ *
+ *   pygobject.c: wrapper for the GObject type.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
+ */
 #include "pygobject-private.h"
 
 static const gchar *pygobject_class_id     = "PyGObject::class";
@@ -781,6 +801,21 @@ pygobject_disconnect(PyGObject *self, PyObject *args)
     return Py_None;
 }
 
+static PyObject *
+pygobject_handler_is_connected(PyGObject *self, PyObject *args)
+{
+    guint handler_id;
+    PyObject *ret;
+
+    if (!PyArg_ParseTuple(args, "i:GObject.handler_is_connected", &handler_id))
+	return NULL;
+
+    ret = g_signal_handler_is_connected(self->obj, handler_id)
+	? Py_True : Py_False;
+    Py_INCREF(ret);
+    return ret;
+}
+
 static PyObject *
 pygobject_handler_block(PyGObject *self, PyObject *args)
 {
@@ -992,6 +1027,7 @@ static PyMethodDef pygobject_methods[] = {
     { "connect_object_after", (PyCFunction)pygobject_connect_object_after, METH_VARARGS },
     { "disconnect", (PyCFunction)pygobject_disconnect, METH_VARARGS },
     { "handler_disconnect", (PyCFunction)pygobject_disconnect, METH_VARARGS },
+    { "handler_is_connected", (PyCFunction)pygobject_handler_is_connected, METH_VARARGS },
     { "handler_block", (PyCFunction)pygobject_handler_block, METH_VARARGS },
     { "handler_unblock", (PyCFunction)pygobject_handler_unblock,METH_VARARGS },
     { "emit", (PyCFunction)pygobject_emit, METH_VARARGS },
